@@ -26,7 +26,7 @@
 #include "callbacks.h"
 #include "prefs.h"
 
-#define XNEST_BIN "/usr/X11R6/bin/Xnest"
+#define XNEST_BIN "/usr/bin/Xephyr"
 
 /* Used by the signal handler to detect which child has died */
 pid_t xnest_pid;
@@ -36,13 +36,28 @@ static gboolean key_event (GtkWidget * widget, GdkEventKey * event,
 
 static void fakeapp_catch_sigchild (int sign);
 
+static char *
+find_spare_dpy (void)
+{
+  int i;
+  char buf[100];   
+  
+  for (i = 0; i < 256; i++) {
+    g_snprintf (buf, sizeof(buf), "/tmp/.X%d-lock", i);
+    if (access (buf, F_OK) != 0) {
+      return g_strdup_printf (":%i", i);
+    }
+  }
+  return NULL;
+}
+
 FakeApp *
 fakeapp_new (void)
 {
   GladeXML *glade;
   FakeApp *app = g_new0 (FakeApp, 1);
 
-  app->xnest_dpy_name = ":1";
+  app->xnest_dpy_name = find_spare_dpy ();
   app->xnest_bin_path = XNEST_BIN;
   app->xnest_bin_options = strdup ("-ac");	/* freed if changed */
 
@@ -99,8 +114,7 @@ fakeapp_new (void)
   app->window = glade_xml_get_widget (glade, "window");
   app->menubar = glade_xml_get_widget (glade, "menubar");
   app->fixed = glade_xml_get_widget (glade, "fixed");
-  gtk_fixed_set_has_window (GTK_FIXED (app->fixed), TRUE);
-
+  app->back = glade_xml_get_widget (glade, "back");
   app->winnest = glade_xml_get_widget (glade, "winnest");
 
   g_signal_connect (app->window, "key-press-event",
@@ -134,7 +148,6 @@ fakeapp_new (void)
 void
 fakeapp_create_gui (FakeApp * app)
 {
-  GdkPixmap *back;
   GdkColor color;
   GdkGC *gc;
   FakeButton *button;
@@ -151,24 +164,15 @@ fakeapp_create_gui (FakeApp * app)
   gtk_fixed_move (GTK_FIXED (app->fixed), app->winnest,
 		  app->device_display_x, app->device_display_y);
 
-  /* Force this widget to have X resources, so we can use it */
+  /* Set the device image */
+  gtk_widget_set_size_request (app->back,
+			       app->device_width,
+			       app->device_height);
+  gtk_fixed_move (GTK_FIXED (app->fixed), app->back, 0, 0);
+  gtk_image_set_from_pixbuf (GTK_IMAGE (app->back), app->device_img);
+
+  /* Now setup the buttons.  Should do this in realize but we can hack that */
   gtk_widget_realize (app->fixed);
-
-  /* Set the device image, by setting the back buffer of the widget */
-  back =
-    gdk_pixmap_new (app->fixed->window, app->device_width, app->device_height,
-		    -1);
-  gc = gdk_gc_new (GDK_DRAWABLE (back));
-  gdk_color_parse ("black", &color);
-  gdk_gc_set_rgb_fg_color (gc, &color);
-  gdk_draw_rectangle (GDK_DRAWABLE (back), gc, TRUE, 0, 0, app->device_width,
-		      app->device_height);
-  gdk_draw_pixbuf (GDK_DRAWABLE (back), NULL, app->device_img, 0, 0, 0, 0, -1,
-		   -1, GDK_RGB_DITHER_NONE, 0, 0);
-  gdk_window_set_back_pixmap (app->fixed->window, back, FALSE);
-  g_object_unref (gc);
-
-  /* Now setup the buttons */
   for (button = app->button_head; button; button = button->next)
     {
       GtkWidget *eventbox;
@@ -324,7 +328,7 @@ fakeapp_start_server (FakeApp * app)
 	{
 	case 0:
 	  setenv ("DISPLAY", app->xnest_dpy_name, 1);
-	  execl ("/bin/sh", "sh", "-c", app->start_cmd, 0);
+	  execl ("/bin/sh", "sh", "-c", app->start_cmd, NULL);
 	  g_warning ("Failed to Launch %s\n", app->start_cmd);
 	  exit (1);
 	case -1:
@@ -384,7 +388,7 @@ int
 main (int argc, char **argv)
 {
   FakeApp *app;
-  char *device = PKGDATADIR "/ipaq3800.xml";
+  char *device = PKGDATADIR "/ipaq4700.xml";
   int i;
 
   gtk_init (&argc, &argv);
